@@ -1,29 +1,11 @@
+#' @keywords internal
+"_PACKAGE"
 
 #' @importFrom checkmate qassert assert_disjunct assert_choice assert_true
-#'
+#' @importFrom checkmate test_class check_class assert
 #' @importFrom data.table copy setDT fifelse fcase :=  %like% %between%
-#'
+#' @importFrom settings options_manager stop_if_reserved reset
 #' @importFrom units as_units deparse_unit
-#'
 #' @importFrom wrapr stop_if_dot_args %?%
-NULL
-
-
-#' Formatting Tools for R Markdown Documents
-#'
-#' Provides a small set of tools for common formatting tasks when writing
-#' documents in R markdown or Quarto markdown. Works with outputs in html,
-#' pdf, docx and possibly others.
-#'
-#'
-#'
-#' @docType package
-#' @name formatdown-package
-#' @aliases formatdown
-#'
-#'
-#' @keywords internal
-#'
-#'
 #'
 NULL
